BindingGenerator

Struct BindingGenerator 

pub struct BindingGenerator;
Generator for binding constants

Implementations

Source

impl BindingGenerator

pub fn generate_bindings_constant(structure_def: &StructureDefinition) -> String

Generate a BINDINGS constant for a StructureDefinition

Returns Rust code as a string containing the static declaration, or an empty string if there are no required bindings.

Uses once_cell::sync::Lazy for runtime initialization.

Example output:

pub static BINDINGS: once_cell::sync::Lazy<Vec<rh_foundation::ElementBinding>> =
    once_cell::sync::Lazy::new(|| vec![
        rh_foundation::ElementBinding::new(
            "Patient.gender",
            rh_foundation::BindingStrength::Required,
            "http://hl7.org/fhir/ValueSet/administrative-gender"
        ).with_description("The gender of the patient"),
    ]);
pub fn generate_bindings_tokens( structure_def: &StructureDefinition, ) -> TokenStream

Generate bindings constant using quote! macro (alternative implementation)