FHIR type metadata structures
This module defines the data structures used for FHIR type metadata that will be generated into the target crate’s metadata.rs file.
Structs
- Field
Info - Information about a field in a FHIR resource or datatype
- Metadata
Registry - Complete metadata registry for all FHIR types
- Type
Metadata - Metadata for a FHIR type (resource or datatype)
Enums
- Fhir
Field Type - FHIR field type (primitive, complex, reference, or backbone element)
- Fhir
Primitive Type - FHIR primitive types