pub struct QualityConfig {
pub run_format: bool,
pub run_compile_check: bool,
pub run_clippy: bool,
}Expand description
Configuration for quality checks
Fields
run_format: boolWhether to run cargo fmt on the generated crate
run_compile_check: boolWhether to run cargo check on the generated crate
run_clippy: boolWhether to run cargo clippy on the generated crate