pub struct PackageDownloader { /* private fields */ }Expand description
FHIR package loader for downloading from npm-style registries.
Implementations
Sourceimpl PackageLoader
impl PackageLoader
Sourcepub fn new(config: LoaderConfig) -> Result<PackageLoader, LoaderError>
pub fn new(config: LoaderConfig) -> Result<PackageLoader, LoaderError>
Create a new package loader with the given configuration.
pub fn is_package_downloaded( &self, package_name: &str, version: &str, output_dir: &Path, ) -> Result<bool, LoaderError>
Sourcepub async fn download_package(
&self,
package_name: &str,
version: &str,
extract_to: &Path,
) -> Result<PackageManifest, LoaderError>
pub async fn download_package( &self, package_name: &str, version: &str, extract_to: &Path, ) -> Result<PackageManifest, LoaderError>
Download a FHIR package and extract it to the specified directory.
Sourcepub fn get_default_packages_dir() -> Result<PathBuf, LoaderError>
pub fn get_default_packages_dir() -> Result<PathBuf, LoaderError>
Get the default FHIR packages directory (~/.fhir/packages).
Sourcepub async fn list_versions(
&self,
package_name: &str,
) -> Result<Vec<String>, LoaderError>
pub async fn list_versions( &self, package_name: &str, ) -> Result<Vec<String>, LoaderError>
List available versions for a package.
Sourcepub async fn get_latest_version(
&self,
package_name: &str,
) -> Result<String, LoaderError>
pub async fn get_latest_version( &self, package_name: &str, ) -> Result<String, LoaderError>
Get the latest version for a package.