Token generation utilities for Rust code emission
This module handles the generation of Rust code tokens from the internal representation, including structs, enums, and modules.
Structs
- Token
Generator - Generates Rust code tokens from internal representations